from __future__ import annotations

from .AFXDataComponent import AFXDataComponent
from .FXScrollArea import FXScrollArea


class AFXBaseTable(FXScrollArea, AFXDataComponent): ...
